@@ -21,6 +21,10 @@
 #include "config.h"
 #endif
 
+#ifdef PLATFORM_OS_OSX
+#include "OSXHelpers.hh"
+#endif
+
 #ifdef HAVE_DISTRIBUTION
 
 #include "debug.hh"
@@ -1036,7 +1040,7 @@ DistributionSocketLink::send_packet_except(PacketBuffer &packet, Client *client)
             {
               c->socket->write(packet.get_buffer(), size, bytes_written);
             }
-          catch (SocketException)
+          catch (SocketException &)
             {
               TRACE_MSG("Failed to send");
             }
@@ -1097,7 +1101,7 @@ DistributionSocketLink::send_packet(Client *client, PacketBuffer &packet)
         {
           client->socket->write(packet.get_buffer(), size, bytes_written);
         }
-      catch (SocketException)
+      catch (SocketException &)
         {
           TRACE_MSG("Failed to send");
         }
@@ -2171,7 +2175,7 @@ DistributionSocketLink::start_async_server()
           ret = true;
         }
     }
-  catch(SocketException e)
+  catch(SocketException &e)
     {
     }
 
@@ -2257,7 +2261,7 @@ DistributionSocketLink::socket_io(ISocket *con, void *data)
     {
       con->read(client->packet.get_write_ptr(), bytes_to_read, bytes_read);
     }
-  catch (SocketException)
+  catch (SocketException &)
     {
       ok = false;
     }
