@@ -46,7 +46,7 @@ UnixInputMonitorFactory::UnixInputMonitorFactory()
 
 
 void
-UnixInputMonitorFactory::init(const std::string &display)
+UnixInputMonitorFactory::init(const char *display)
 {
   this->display = display;
 }
