@@ -46,81 +46,94 @@
 
 using namespace workrave;
 
-W32AlternateMonitor::W32AlternateMonitor() : 
-  thread_id( 0 )
+
+W32AlternateMonitor::W32AlternateMonitor() :
+	initialized( false ),
+	interval( 500 ),
+	thread_abort_event( NULL ),
+	thread_handle( NULL ),
+	thread_id( 0 )
 {
   TRACE_ENTER( "W32AlternateMonitor::W32AlternateMonitor" );
-  
-  CoreFactory::get_configurator()->get_value_with_default( "advanced/interval", interval, 500);
-  
+
   TRACE_EXIT();
 }
 
+
 W32AlternateMonitor::~W32AlternateMonitor()
 {
   TRACE_ENTER( "W32AlternateMonitor::~W32AlternateMonitor" );
-  
+
   terminate();
-  
+
   TRACE_EXIT();
 }
 
 
 bool W32AlternateMonitor::init()
 {
-  TRACE_ENTER( "W32AlternateMonitor::init" );
-  
-  /* Try to get the address of GetLastInputInfo()... */
-  GetLastInputInfo = ( BOOL ( WINAPI * ) ( LASTINPUTINFO * ) )
-    GetProcAddress( GetModuleHandleA( "user32.dll" ), "GetLastInputInfo" );
-  
-  if( GetLastInputInfo == NULL )
-  /*
-    GetLastInputInfo() is only available in Win2000 or better.
-    AdvancedPreferencePage and ActivityMonitor check the OS using
-    GetVersion(), so it shouldn't come to this.
-  */
-  {
-    TRACE_MSG( "GetLastInputInfo() address not found in user32.dll" );
-    TRACE_EXIT();
-    return false;
-  }
-  
-  thread_id = 0;
-  SetLastError( 0 );
-  thread_handle = CreateThread( NULL, 0, thread_Monitor, this, 0, (DWORD *)&thread_id );
-  
-  if( thread_handle == NULL || thread_id == 0 )
-  {
-    TRACE_MSG( "Thread could not be created. GetLastError : " << GetLastError() );
-    TRACE_EXIT();
-    return false;
-  }
-  
-  /* Close the handle now, we don't need it anymore. */
-  CloseHandle( thread_handle );
-  thread_handle = NULL;
-  
-  Harpoon::init( NULL );
-  
-  TRACE_EXIT();
-  return true;
+	TRACE_ENTER( "W32AlternateMonitor::init" );
+
+	if( initialized )
+		goto cleanup;
+
+	CoreFactory::get_configurator()->get_value_with_default( "advanced/interval", interval, 500 );
+
+	SetLastError( 0 );
+	thread_abort_event = CreateEvent( NULL, FALSE, FALSE, NULL );
+	if( !thread_abort_event )
+	{
+		TRACE_MSG( "Thread abort event could not be created. GetLastError : " << GetLastError() );
+		goto cleanup;
+	}
+
+	thread_id = 0;
+	SetLastError( 0 );
+	thread_handle = CreateThread( NULL, 0, thread_Monitor, this, 0, (DWORD *)&thread_id );
+	if( !thread_handle || !thread_id )
+	{
+		TRACE_MSG( "Thread could not be created. GetLastError : " << GetLastError() );
+		goto cleanup;
+	}
+
+	Harpoon::init( NULL );
+	
+	initialized = true;
+
+cleanup:
+	if( initialized == false )
+		terminate();
+
+	TRACE_EXIT();
+	return initialized;
 }
 
+
 void W32AlternateMonitor::terminate()
 {
-  TRACE_ENTER( "W32AlternateMonitor::terminate" );
-  
-  if( thread_id )
-    {
-	  TRACE_MSG( "Terminating thread id: " << thread_id );
-      PostThreadMessage( thread_id, WM_QUIT, 0, 0 );
-      thread_id = 0;
-    }
-  
-  Harpoon::terminate();
+	TRACE_ENTER( "W32AlternateMonitor::terminate" );
 
-  TRACE_EXIT();
+	thread_id = 0;
+
+	if( thread_handle )
+	{
+		SetEvent( thread_abort_event );
+		WaitForSingleObject( thread_handle, INFINITE );
+		CloseHandle( thread_handle );
+		thread_handle = NULL;
+	}
+
+	if( thread_abort_event )
+	{
+		CloseHandle( thread_abort_event );
+		thread_abort_event = NULL;
+	}
+
+	Harpoon::terminate();
+	
+	initialized = false;
+
+	TRACE_EXIT();
 }
 
 
@@ -128,23 +141,24 @@ DWORD WINAPI W32AlternateMonitor::thread_Monitor( LPVOID lpParam )
 {
   W32AlternateMonitor *pThis = (W32AlternateMonitor *) lpParam;
   pThis->Monitor();
+  // invalidate the id to signal the thread is exiting
+  pThis->thread_id = 0;
   return (DWORD) 0;
 }
 
+
 void W32AlternateMonitor::Monitor()
 {
   const DWORD current_thread_id = GetCurrentThreadId();
-  
+
   TRACE_ENTER_MSG( "W32AlternateMonitor::Monitor [ id: ", current_thread_id << " ]" );
-  
-  assert( GetLastInputInfo );
-  
+
   SetThreadPriority( GetCurrentThread(), THREAD_PRIORITY_BELOW_NORMAL );
-  
-  
+
+
   LASTINPUTINFO lii;
   DWORD dwPreviousTime = 0;
-  
+
   lii.cbSize = sizeof( lii );
   lii.dwTime = GetTickCount();
   
@@ -152,18 +166,18 @@ void W32AlternateMonitor::Monitor()
   /* Main loop */
   {
     dwPreviousTime = lii.dwTime;
-    
-    if( ( *GetLastInputInfo )( &lii ) && lii.dwTime > dwPreviousTime )
+
+    if( GetLastInputInfo( &lii ) && ( lii.dwTime > dwPreviousTime ) )
     /* User session has received input */
     {
       /* Notify the activity monitor */
       fire_action();
     }
-    
-    Sleep( interval );
+
+    if( WaitForSingleObject( thread_abort_event, interval ) != WAIT_TIMEOUT )
+      break;
   }
-  
-  
+
   TRACE_EXIT();
 }
 
