@@ -92,7 +92,8 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
   lock_button(NULL),
   postpone_button(NULL),
   skip_button(NULL),
-  sysoper_combobox(NULL)
+  sysoper_combobox(NULL),
+  progress_bar(NULL)
 #ifdef PLATFORM_OS_WIN32
   ,
   desktop_window( NULL ),
@@ -495,29 +496,39 @@ BreakWindow::create_lock_button()
 }
 
 void
-BreakWindow::update_skip_postpone_sensitivity()
+BreakWindow::update_skip_postpone_lock()
 {
-  if (postpone_button != NULL && !postpone_button->get_sensitive())
+  if ( (postpone_button != NULL && !postpone_button->get_sensitive()) ||
+       (skip_button != NULL && !skip_button->get_sensitive()))
     {
-      if (!is_non_ignorable_break_overdue())
+      bool skip_locked = false;
+      bool postpone_locked = false;
+      BreakId overdue_break_id = BREAK_ID_NONE;
+      check_skip_postpone_lock(skip_locked, postpone_locked, overdue_break_id);
+
+      if (progress_bar)
         {
-          if (postpone_button != NULL)
+          if (overdue_break_id != BREAK_ID_NONE)
             {
-              postpone_button->set_has_tooltip(false);
-              postpone_button->set_sensitive(true);
+              ICore *core = CoreFactory::get_core();
+              IBreak *b = core->get_break(BreakId(overdue_break_id));
+              progress_bar->set_fraction(1.0 - ((double)b->get_elapsed_idle_time()) / b->get_auto_reset());
+            }
+          else
+            {
+              progress_bar->hide();
             }
         }
-    }
 
-  if (skip_button != NULL && !skip_button->get_sensitive())
-    {
-      if (!is_non_skipable_break_overdue())
+      if (!postpone_locked && postpone_button != NULL)
         {
-          if (skip_button != NULL)
-            {
-              skip_button->set_has_tooltip(false);
-              skip_button->set_sensitive(true); 
-            }
+          postpone_button->set_has_tooltip(false);
+          postpone_button->set_sensitive(true);
+        }
+      if (!skip_locked && skip_button != NULL)
+        {
+          skip_button->set_has_tooltip(false);
+          skip_button->set_sensitive(true);
         }
     }
 }
@@ -576,11 +587,15 @@ BreakWindow::on_lock_button_clicked()
   System::execute(System::SystemOperation::SYSTEM_OPERATION_LOCK_SCREEN);
 }
 
-
-bool
-BreakWindow::is_non_ignorable_break_overdue()
+void
+BreakWindow::check_skip_postpone_lock(bool &skip_locked, bool &postpone_locked, BreakId &overdue_break_id)
 {
-  TRACE_ENTER("BreakWindow::is_non_ignorable_break_overdue");
+  TRACE_ENTER("BreakWindow::check_skip_postpone_lock");
+
+  skip_locked = false;
+  postpone_locked = false;
+  overdue_break_id = BREAK_ID_NONE;
+
   ICore *core = CoreFactory::get_core();
   OperationMode mode = core->get_operation_mode();
 
@@ -588,90 +603,132 @@ BreakWindow::is_non_ignorable_break_overdue()
     {
       for (int id = break_id - 1; id >= 0; id--)
         {
+          IBreak *b = core->get_break(BreakId(id));
+          bool overdue = b->get_elapsed_time() > b->get_limit();
+
           if (!GUIConfig::get_ignorable(BreakId(id)))
             {
-              IBreak *b = core->get_break(BreakId(id));
-              if (b->get_elapsed_time() > b->get_limit())
-                {
-                  return true;
-                }
+              skip_locked = overdue;
             }
-        }
-    }
-  return false;
-}
-
-bool
-BreakWindow::is_non_skipable_break_overdue()
-{
-  TRACE_ENTER("BreakWindow::is_non_skipable_break_overdue");
-  ICore *core = CoreFactory::get_core();
-  OperationMode mode = core->get_operation_mode();
-
-  if (! (break_flags & BreakWindow::BREAK_FLAGS_USER_INITIATED) && mode == OPERATION_MODE_NORMAL)
-    {
-      for (int id = break_id - 1; id >= 0; id--)
-        {
           if (!GUIConfig::get_skippable(BreakId(id)))
             {
-              IBreak *b = core->get_break(BreakId(id));
-              if (b->get_elapsed_time() > b->get_limit())
-                {
-                  return true;
-                }
+              postpone_locked = overdue;
+            }
+          if (skip_locked || postpone_locked)
+            {
+              overdue_break_id = BreakId(id);
+              return;
             }
         }
     }
-  return false;
 }
 
-
 //! Control buttons.
 Gtk::Box *
 BreakWindow::create_bottom_box(bool lockable,
                                bool shutdownable)
 {
-  Gtk::HBox *box = NULL;
 
   accel_group = Gtk::AccelGroup::create();
   add_accel_group(accel_group);
 
+  Gtk::VBox *vbox = new Gtk::VBox(false, 0);
+
+  button_size_group = Gtk::SizeGroup::create(Gtk::SIZE_GROUP_HORIZONTAL);
+  box_size_group = Gtk::SizeGroup::create(Gtk::SIZE_GROUP_HORIZONTAL);
+
   if ((break_flags != BREAK_FLAGS_NONE) || lockable || shutdownable)
     {
-      box = new Gtk::HBox(false, 6);
+      Gtk::HBox *top_box = Gtk::manage(new Gtk::HBox(false, 0));
+      Gtk::HBox *bottom_box = Gtk::manage(new Gtk::HBox(false, 6));
+
+      vbox->pack_end(*bottom_box, Gtk::PACK_SHRINK, 2);
 
       if (break_flags != BREAK_FLAGS_NONE)
         {
-          Gtk::HButtonBox *button_box = new Gtk::HButtonBox(Gtk::BUTTONBOX_END, 6);
+          Gtk::HButtonBox *button_box = Gtk::manage(new Gtk::HButtonBox(Gtk::BUTTONBOX_END, 6));
+          bottom_box->pack_end(*button_box, Gtk::PACK_SHRINK, 0);
+
+          bool skip_locked = false;
+          bool postpone_locked = false;
+          BreakId overdue_break_id =  BREAK_ID_NONE;
+          check_skip_postpone_lock(skip_locked, postpone_locked, overdue_break_id);
 
           if ((break_flags & BREAK_FLAGS_SKIPPABLE) != 0)
             {
-              bool enabled = !is_non_skipable_break_overdue();
-
               skip_button = create_skip_button();
-              skip_button->set_sensitive(enabled);
-              if (!enabled)
+              skip_button->set_sensitive(!skip_locked);
+              if (skip_locked)
                 {
                   const char *msg = _("You cannot skip this break while another non-skippable break is overdue.");
                   skip_button->set_tooltip_text(msg);
                 }
-              button_box->pack_end(*skip_button, Gtk::PACK_SHRINK, 0);
+
+              button_box->pack_end(*skip_button, Gtk::PACK_EXPAND_WIDGET, 0);
+              button_size_group->add_widget(*skip_button);
             }
 
           if ((break_flags & BREAK_FLAGS_POSTPONABLE) != 0)
             {
-              bool enabled = !is_non_ignorable_break_overdue();
-
               postpone_button = create_postpone_button();
-              postpone_button->set_sensitive(enabled);
-              if (!enabled)
+              postpone_button->set_sensitive(!postpone_locked);
+              if (postpone_locked)
                 {
                   const char *msg = _("You cannot postpone this break while another non-postponable break is overdue.");
                   postpone_button->set_tooltip_text(msg);
                 }
-              button_box->pack_end(*postpone_button, Gtk::PACK_SHRINK, 0);
+              button_box->pack_end(*postpone_button, Gtk::PACK_EXPAND_WIDGET, 0);
+              button_size_group->add_widget(*postpone_button);
+            }
+
+          if (skip_locked || postpone_locked)
+            {
+              Gtk::HBox *progress_bar_box = Gtk::manage(new Gtk::HBox(false, 0));
+
+              progress_bar = Gtk::manage(new Gtk::ProgressBar);
+#ifdef HAVE_GTK3
+              progress_bar->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+#else
+              progress_bar->set_orientation(Gtk::PROGRESS_LEFT_TO_RIGHT);
+#endif
+              progress_bar->set_fraction(0);
+              progress_bar->set_name("locked-progress");
+              update_skip_postpone_lock();
+
+              vbox->pack_end(*top_box, Gtk::PACK_SHRINK, 0);
+              top_box->pack_end(*progress_bar_box, Gtk::PACK_SHRINK, 0);
+
+              Gtk::Alignment *align;
+              if (skip_locked && postpone_locked)
+                {
+                  align = Gtk::manage(new Gtk::Alignment(0, 0, 1.0, 0.0));
+                }
+              else if (skip_locked)
+                {
+                  align = Gtk::manage(new Gtk::Alignment(0, 1, 0.0, 0.0));
+                }
+              else
+                {
+                  align = Gtk::manage(new Gtk::Alignment(1, 0, 0, 0.0));
+                }
+              align->add(*progress_bar);
+              progress_bar_box->pack_end(*align, Gtk::PACK_EXPAND_WIDGET, 6);
+
+              box_size_group->add_widget(*progress_bar_box);
+              box_size_group->add_widget(*button_box);
+              button_size_group->add_widget(*progress_bar);
+
+#if GTK_CHECK_VERSION(3,0,0)
+              const char style[] =
+                "progress, trough {\n"
+                "min-width: 1px;\n"
+                "}";
+              Glib::RefPtr<Gtk::CssProvider> css_provider = Gtk::CssProvider::create();
+              Glib::RefPtr<Gtk::StyleContext> style_context = progress_bar->get_style_context();
+              css_provider->load_from_data(style);
+              style_context->add_provider(css_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+#endif
             }
-          box->pack_end(*button_box, Gtk::PACK_SHRINK, 0);
         }
 
       //#ifdef HAVE_GTK3
@@ -682,7 +739,7 @@ BreakWindow::create_bottom_box(bool lockable,
               sysoper_combobox = create_sysoper_combobox();
               if (sysoper_combobox != NULL)
                 {
-                  box->pack_end(*sysoper_combobox, Gtk::PACK_SHRINK, 0);
+                  bottom_box->pack_end(*sysoper_combobox, Gtk::PACK_SHRINK, 0);
                 }
             }
           else
@@ -690,7 +747,7 @@ BreakWindow::create_bottom_box(bool lockable,
               lock_button = create_lock_button();
               if (lock_button != NULL)
                 {
-                  box->pack_end(*lock_button, Gtk::PACK_SHRINK, 0);
+                  bottom_box->pack_end(*lock_button, Gtk::PACK_SHRINK, 0);
                 }
             }
         }
@@ -698,7 +755,7 @@ BreakWindow::create_bottom_box(bool lockable,
 
     }
 
-  return box;
+  return vbox;
 }
 
 
@@ -731,6 +788,16 @@ BreakWindow::start()
 {
   TRACE_ENTER("BreakWindow::start");
 
+  // Need to realize window before it is shown
+  // Otherwise, there is not gobj()...
+  realize_if_needed();
+
+  // Set some window hints.
+  set_skip_pager_hint(true);
+  set_skip_taskbar_hint(true);
+
+  WindowHints::set_always_on_top(this, true);
+
   update_break_window();
   center();
 
@@ -740,11 +807,7 @@ BreakWindow::start()
 #endif
   show_all();
 
-  // Set window hints.
-  set_skip_pager_hint(true);
-  set_skip_taskbar_hint(true);
   WindowHints::set_always_on_top(this, true);
-  raise();
 
 #ifdef PLATFORM_OS_WIN32
   if( force_focus_on_break_start && ( this->head.count == 0 ) )
@@ -765,7 +828,7 @@ BreakWindow::start()
       // button that still has 'can focus' set to true.
       // So, unset 'can focus' of this button...
       disable_button_focus(GTK_WIDGET(sysoper_combobox->gobj()));
-      
+
       // ...and clear the focus of the break window, which already focussed
       // the button.
       GtkWidget *toplevel = gtk_widget_get_toplevel(GTK_WIDGET(sysoper_combobox->gobj()));
@@ -823,7 +886,7 @@ BreakWindow::refresh()
 {
   TRACE_ENTER("BreakWindow::refresh");
 
-  update_skip_postpone_sensitivity();
+  update_skip_postpone_lock();
 
   update_break_window();
 
