@@ -424,3 +424,22 @@ GtkUtil::running_on_wayland()
   return false;
 #endif
 }
+
+
+void
+GtkUtil::set_theme_fg_color(Gtk::Widget *widget)
+{
+#if GTK_CHECK_VERSION(3,0,0)
+  const char style[] =
+  "* {\n"
+  "color: @theme_fg_color;\n"
+  "}";
+
+  Glib::RefPtr<Gtk::CssProvider> css_provider = Gtk::CssProvider::create();
+  Glib::RefPtr<Gtk::StyleContext> style_context = widget->get_style_context();
+
+  css_provider->load_from_data(style);
+  style_context->add_provider(css_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+#endif
+}
+
