@@ -55,6 +55,7 @@
 #include "DataConnector.hh"
 
 #include "CoreFactory.hh"
+#include "CoreConfig.hh"
 #include "IConfigurator.hh"
 
 #ifdef HAVE_DISTRIBUTION
@@ -70,8 +71,6 @@
 #endif
 
 
-// #include "PluginsPreferencePage.hh"
-
 #define RUNKEY "Software\\Microsoft\\Windows\\CurrentVersion\\Run"
 
 using namespace std;
@@ -86,6 +85,11 @@ PreferencesDialog::PreferencesDialog()
     sound_play_button(NULL),
     fsbutton(NULL),
     filefilter(NULL)
+#ifdef PLATFORM_OS_WIN32
+    ,
+    sensitivity_adjustment(3, 0, 100),
+    sensitivity_box(NULL)
+#endif
 {
   TRACE_ENTER("PreferencesDialog::PreferencesDialog");
 
@@ -536,14 +540,14 @@ PreferencesDialog::create_timer_page()
 #if defined(PLATFORM_OS_WIN32)
   Gtk::Widget *box = Gtk::manage(GtkUtil::create_label("Monitoring", false));
   Gtk::Widget *monitoring_page = create_monitoring_page();
-  
+
 #ifdef HAVE_GTK3
   tnotebook->append_page(*monitoring_page , *box);
 #else
   tnotebook->pages().push_back(Gtk::Notebook_Helpers::TabElem(*monitoring_page, *box));
 #endif
 #endif
-  
+
   return tnotebook;
 }
 
@@ -559,19 +563,28 @@ PreferencesDialog::create_monitoring_page()
   monitor_type_cb->add(*monitor_type_lab);
   monitor_type_cb->signal_toggled().connect(sigc::mem_fun(*this, &PreferencesDialog::on_monitor_type_toggled));
   panel->pack_start(*monitor_type_cb, false, false, 0);
-  
+
   Gtk::Label *monitor_type_help = Gtk::manage(GtkUtil::create_label(_("Enable this option if Workrave fails to detect when you are using your computer"), false));
   panel->pack_start(*monitor_type_help, false, false, 0);
 
+  sensitivity_box = Gtk::manage(new Gtk::HBox());
+  Gtk::Widget *sensitivity_lab = Gtk::manage(GtkUtil::create_label_with_tooltip(_("Mouse sensitivity:"), _("Number of pixels the mouse should move before it is considered activity.")));
+  Gtk::SpinButton *sensitivity_spin = Gtk::manage(new Gtk::SpinButton(sensitivity_adjustment));
+  sensitivity_box->pack_start(*sensitivity_lab, false, false, 0);
+  sensitivity_box->pack_start(*sensitivity_spin, false, false, 0);
+  panel->pack_start(*sensitivity_box, false, false, 0);
+
+  connector->connect(CoreConfig::CFG_KEY_MONITOR_SENSITIVITY, dc::wrap(&sensitivity_adjustment));
+
   string monitor_type;
   CoreFactory::get_configurator()->get_value_with_default("advanced/monitor",
                                                           monitor_type,
                                                           "default");
 
-
-  
   monitor_type_cb->set_active(monitor_type != "default");
 
+  sensitivity_box->set_sensitive(monitor_type != "default");
+
   return panel;
 }
 
@@ -796,6 +809,7 @@ PreferencesDialog::on_monitor_type_toggled()
 {
   bool on = monitor_type_cb->get_active();
   CoreFactory::get_configurator()->set_value("advanced/monitor", on ? "lowlevel" : "default");
+  sensitivity_box->set_sensitive(on);
 }
 #endif
 
@@ -991,4 +1005,3 @@ PreferencesDialog::update_theme_selection()
     }
   TRACE_EXIT();
 }
-
