@@ -32,6 +32,7 @@
 
 #include "TimeBar.hh"
 #include "Text.hh"
+#include "GtkUtil.hh"
 
 const int MARGINX = 4;
 const int MARGINY = 2;
@@ -67,8 +68,9 @@ TimeBar::TimeBar() :
   set_bar_color(COLOR_ID_INACTIVE);
   set_secondary_bar_color(COLOR_ID_INACTIVE);
   set_text_color(Gdk::Color("black"));
-}
 
+  GtkUtil::set_theme_fg_color(this);
+}
 
 //! Destructor
 TimeBar::~TimeBar()
@@ -695,6 +697,8 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
                bar_width, bar_height, win_lw, win_lh);
     }
 
+  style_context->context_restore();
+  style_context->context_save();
 
   // Text
   Pango::Matrix matrix = PANGO_MATRIX_INIT;
@@ -779,13 +783,12 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
   set_color(cr, bar_text_color);
   pl1->show_in_cairo_context(cr);
 
-  Gdk::RGBA front_color = style_context->get_color();
   cr->reset_clip();
   cr->rectangle(rect2.get_x(), rect2.get_y(), rect2.get_width(), rect2.get_height());
   cr->clip();
 
-  cr->set_operator(Cairo::OPERATOR_XOR);
-  cr->set_source_rgba(1,1,1,1);
+
+  set_color(cr, style_context->get_color(Gtk::STATE_FLAG_ACTIVE));
   cr->move_to(text_x, text_y);
   pl1->show_in_cairo_context(cr);
   style_context->context_restore();
