@@ -6,87 +6,140 @@
 #pragma comment(lib, "user32.lib")
 
 #pragma warning(push)
-#pragma warning(disable:4100) //unreferenced formal parameter
+#pragma warning(disable : 4100) //unreferenced formal parameter
 
-typedef DWORD (__stdcall *QUERYFULLPROCESSIMAGENAME)(HANDLE, DWORD, LPTSTR, PDWORD);
-typedef DWORD (__stdcall *GETMODULEFILENAMEEX)(HANDLE, HMODULE, LPTSTR, DWORD);
-typedef DWORD (__stdcall *GETMODULEBASENAME)(HANDLE, HMODULE, LPTSTR, DWORD);
-typedef BOOL  (__stdcall *ENUMPROCESSES)(DWORD *, DWORD, DWORD *);
-typedef BOOL  (__stdcall *ENUMPROCESSMODULES)(HANDLE, HMODULE *, DWORD, LPDWORD);
+typedef DWORD(__stdcall *QUERYFULLPROCESSIMAGENAME)(HANDLE, DWORD, LPTSTR, PDWORD);
+typedef DWORD(__stdcall *GETMODULEFILENAMEEX)(HANDLE, HMODULE, LPTSTR, DWORD);
+typedef DWORD(__stdcall *GETMODULEBASENAME)(HANDLE, HMODULE, LPTSTR, DWORD);
+typedef BOOL(__stdcall *ENUMPROCESSES)(DWORD *, DWORD, DWORD *);
+typedef BOOL(__stdcall *ENUMPROCESSMODULES)(HANDLE, HMODULE *, DWORD, LPDWORD);
 
 static QUERYFULLPROCESSIMAGENAME pfnQueryFullProcessImageName = NULL;
-static GETMODULEFILENAMEEX       pfnGetModuleFileNameEx = NULL;
-static ENUMPROCESSES             pfnEnumProcesses = NULL;
-static ENUMPROCESSMODULES        pfnEnumProcessModules = NULL;
-static GETMODULEBASENAME         pfnGetModuleBaseName = NULL;
+static GETMODULEFILENAMEEX pfnGetModuleFileNameEx = NULL;
+static ENUMPROCESSES pfnEnumProcesses = NULL;
+static ENUMPROCESSMODULES pfnEnumProcessModules = NULL;
+static GETMODULEBASENAME pfnGetModuleBaseName = NULL;
 
 static BOOL success = FALSE;
 static BOOL simulate = FALSE;
 
-BOOL CALLBACK EnumWindowsProc(HWND hwnd, long lParam)
+#define MAX_CLASS_NAME (128)
+#define MAX_TITLE (128)
+
+enum Kind
 {
-    BOOL func_retval = TRUE;
-    DWORD processid = 0;
-    HANDLE process_handle = NULL;
-    char *ptr = NULL;
-    char buf[ 2 * MAX_PATH ] = { 0, };
-    BOOL process_name_found = FALSE;
-    int n = 0;
+  KIND_NONE,
+  KIND_EGG,
+  KIND_MENU
+};
 
-    n = GetClassName( hwnd, (LPSTR)buf, sizeof( buf ) - 1 );
-    if( n <= 0 )
-        goto cleanup;
+static BOOL
+GetProcessName(HWND hwnd, char *buf, size_t buf_size)
+{
+  HANDLE process_handle = NULL;
+  BOOL process_name_found = FALSE;
+  DWORD processid = 0;
 
-    buf[ n ] = '\0';
-
-    if( strcmp( buf, "EggSmClientWindow" ) )
-        goto cleanup;
-
-    if( !GetWindowThreadProcessId( hwnd, &processid )
-        || !processid
-        )
-        goto cleanup;
-
-    process_handle = OpenProcess( PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, 0, processid );
-    if( !process_handle )
-        goto cleanup;
-
-    if( pfnQueryFullProcessImageName )
+  if (GetWindowThreadProcessId(hwnd, &processid) && processid != 0)
     {
-        DWORD buf_size = sizeof( buf );
-        if( pfnQueryFullProcessImageName( process_handle, 0, buf, &buf_size ) )
-            process_name_found = TRUE;
+      process_handle = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, 0, processid);
+      if (process_handle != 0)
+        {
+          if (pfnQueryFullProcessImageName != NULL)
+            {
+              DWORD size = buf_size;
+              if (pfnQueryFullProcessImageName(process_handle, 0, buf, &size))
+                {
+                  process_name_found = TRUE;
+                }
+            }
+
+          if (!process_name_found && pfnGetModuleFileNameEx)
+            {
+              if (pfnGetModuleFileNameEx(process_handle, NULL, buf, buf_size))
+                {
+                  process_name_found = TRUE;
+                }
+            }
+          CloseHandle(process_handle);
+        }
     }
-
-    if( !process_name_found && pfnGetModuleFileNameEx )
-    {
-        if( pfnGetModuleFileNameEx( process_handle, NULL, buf, sizeof( buf ) ) )
-            process_name_found = TRUE;
-    }
-
-    if( !process_name_found )
-        goto cleanup;
-
-    ptr = strrchr( buf, '\\' );
-    if( !ptr
-        || _stricmp( ptr + 1, "Workrave.exe" )
-        )
-        goto cleanup;
-
-    if( !simulate )
-        PostMessage( hwnd, WM_ENDSESSION, 1, 0 );
-
-    success = TRUE;
-    func_retval = FALSE;
-
-cleanup:
-
-    if( process_handle )
-        CloseHandle( process_handle );
-
-    return func_retval;
+  return process_name_found;
 }
 
+static void
+SendQuit(HWND hwnd, enum Kind kind)
+{
+  switch (kind)
+    {
+      case KIND_NONE:
+        break;
+
+      case KIND_EGG:
+        PostMessage(hwnd, WM_ENDSESSION, 1, 0);
+        break;
+
+      case KIND_MENU:
+        PostMessage(hwnd, WM_USER, 14, 0);
+        break;
+    }
+}
+
+BOOL CALLBACK
+EnumWindowsProc(HWND hwnd, long lParam)
+{
+  char className[MAX_CLASS_NAME] = { 0, };
+  char title[MAX_TITLE] = { 0,  };
+  char processName[2 * MAX_PATH] = { 0, };
+  int n = 0;
+  enum Kind kind = KIND_NONE;
+
+  n = GetClassName(hwnd, (LPSTR)className, sizeof(className) - 1);
+  if (n < 0)
+    {
+      n = 0;
+    }
+  className[n] = '\0';
+  // printf("className = %s\n", className);
+
+  n = GetWindowText(hwnd, (LPSTR)title, sizeof(title) - 1);
+  if (n < 0)
+    {
+      n = 0;
+    }
+  title[n] = '\0';
+  // printf("title = %s\n", title);
+  
+  if (strcmp(className, "EggSmClientWindow") == 0)
+    {
+      kind = KIND_EGG;
+    }
+  else if ((strcmp(className, "gdkWindowToplevel") == 0) && (strcmp(title, "Workrave") == 0))
+    {
+      kind = KIND_MENU;
+    }
+  // printf("kind = %d\n", kind);
+
+  if (kind != KIND_NONE)
+    {
+      BOOL ret = GetProcessName(hwnd, processName, sizeof(processName));
+
+      if (ret)
+        {
+          // printf("processName = %s\n", processName);
+          char *ptr = strrchr(processName, '\\');
+          if (ptr != NULL && _stricmp(ptr + 1, "Workrave.exe" ) == 0)
+            {
+              success = TRUE;
+              if (!simulate)
+                {
+                  SendQuit(hwnd, kind);
+                }
+            }
+        }
+    }
+  return !success;
+}
 
 static void
 FindOrZapWorkrave()
@@ -121,7 +174,6 @@ FindOrZapWorkrave()
     }
 }
 
-
 BOOL
 FindWorkrave()
 {
@@ -147,7 +199,7 @@ ZapWorkrave()
 BOOL
 KillProcess(char *proces_name_to_kill)
 {
-  HINSTANCE psapi =  psapi = LoadLibrary("psapi.dll");
+  HINSTANCE psapi = psapi = LoadLibrary("psapi.dll");
   BOOL ret = FALSE;
 
   pfnEnumProcesses = (ENUMPROCESSES)GetProcAddress(psapi, "EnumProcesses");
@@ -167,12 +219,12 @@ KillProcess(char *proces_name_to_kill)
           count += 1024;
           pids = realloc(pids, count * sizeof(DWORD));
           ret = pfnEnumProcesses(pids, count * sizeof(DWORD), &needed);
-
-        } while (ret && needed > (count * sizeof(DWORD)));
+        }
+      while (ret && needed > (count * sizeof(DWORD)));
 
       if (ret)
         {
-          count = needed / sizeof (DWORD);
+          count = needed / sizeof(DWORD);
 
           for (i = 0; i < count; i++)
             {
@@ -193,7 +245,7 @@ KillProcess(char *proces_name_to_kill)
 
                   if (pfnEnumProcessModules(process_handle, &module_handle, sizeof(module_handle), &cbNeeded))
                     {
-                      pfnGetModuleBaseName(process_handle, module_handle, process_name, sizeof(process_name)/sizeof(char));
+                      pfnGetModuleBaseName(process_handle, module_handle, process_name, sizeof(process_name) / sizeof(char));
                     }
 
                   if (_stricmp(process_name, proces_name_to_kill) == 0)
