@@ -1,6 +1,6 @@
 // NetworkLogDialog.cc --- NetworkLog dialog
 //
-// Copyright (C) 2002, 2003, 2006, 2007, 2008 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2006, 2007, 2008, 2011 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -46,7 +46,11 @@
 #include "Util.hh"
 
 NetworkLogDialog::NetworkLogDialog()
-  : Gtk::Dialog(_("Network log"), false, true)
+#ifdef HAVE_GTK3
+  : Gtk::Dialog(_("Network log"), false)
+#else
+    : Gtk::Dialog(_("Network log"), false, true)
+#endif
 {
   TRACE_ENTER("NetworkLogDialog::NetworkLogDialog");
 
@@ -93,7 +97,11 @@ NetworkLogDialog::distribution_log(std::string msg)
 {
   Gtk::TextIter iter = text_buffer->end();
   iter = text_buffer->insert(iter, msg);
+#ifdef HAVE_GTK3
+  Glib::RefPtr<Gtk::Adjustment> a = scrolled_window.get_vadjustment();
+#else
   Gtk::Adjustment *a = scrolled_window.get_vadjustment();
+#endif
   a->set_value(a->get_upper());
 }
 
@@ -115,7 +123,11 @@ NetworkLogDialog::init()
         }
 
       dist_manager->add_log_listener(this);
+#ifdef HAVE_GTK3
+      Glib::RefPtr<Gtk::Adjustment> a = scrolled_window.get_vadjustment();
+#else
       Gtk::Adjustment *a = scrolled_window.get_vadjustment();
+#endif
       a->set_value(a->get_upper());
     }
 }
