@@ -1,6 +1,6 @@
 // NetworkPreferencePage.cc --- Preferences widgets for a timer
 //
-// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2010 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2004, 2006, 2007, 2008, 2010, 2013 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software: you can redistribute it and/or modify
@@ -100,18 +100,18 @@ NetworkPreferencePage::create_general_page(Gtk::Notebook *tnotebook)
   HigCategoryPanel *id_frame = Gtk::manage(new HigCategoryPanel(*enabled_cb));
   username_entry = Gtk::manage(new Gtk::Entry());
   password_entry = Gtk::manage(new Gtk::Entry());
-  id_frame->add(_("Username:"), *username_entry);
-  id_frame->add(_("Password:"), *password_entry);
+  id_frame->add_label(_("Username:"), *username_entry);
+  id_frame->add_label(_("Password:"), *password_entry);
   password_entry->set_visibility(false);
   password_entry->set_invisible_char('*');
- 
+
   // Server switch
   listening_cb = Gtk::manage(new Gtk::CheckButton());
   Gtk::Label *listening_lab
     = Gtk::manage(GtkUtil::create_label(_("Allow incoming connections"), true));
   listening_cb->add(*listening_lab);
-  id_frame->add(*listening_cb);
- 
+  id_frame->add_widget(*listening_cb);
+
   id_frame->set_border_width(12);
   tnotebook->append_page(*id_frame, _("General"));
 
@@ -148,9 +148,9 @@ NetworkPreferencePage::create_advanced_page(Gtk::Notebook *tnotebook)
   interval_entry->set_numeric(true);
   interval_entry->set_width_chars(10);
 
-  advanced_frame->add(_("Server port:"), *port_entry);
-  advanced_frame->add(_("Reconnect attempts:"), *attempts_entry);
-  advanced_frame->add(_("Reconnect interval:"), *interval_entry);
+  advanced_frame->add_label(_("Server port:"), *port_entry);
+  advanced_frame->add_label(_("Reconnect attempts:"), *attempts_entry);
+  advanced_frame->add_label(_("Reconnect interval:"), *interval_entry);
 
   advanced_frame->set_border_width(12);
   tnotebook->append_page(*advanced_frame, _("Advanced"));
@@ -214,7 +214,7 @@ NetworkPreferencePage::create_peers_page(Gtk::Notebook *tnotebook)
   renderer->property_editable().set_value(true);
   renderer->signal_edited().connect(sigc::mem_fun(*this, &NetworkPreferencePage::on_port_edited));
 
-  
+
   Gtk::ScrolledWindow *peers_scroll = Gtk::manage(new Gtk::ScrolledWindow());
   peers_scroll->add(*peers_list);
 
@@ -243,7 +243,7 @@ NetworkPreferencePage::create_peers_page(Gtk::Notebook *tnotebook)
   gp->pack_start(*hbox, true, true, 0);
 
   create_model();
-  
+
   gp->show_all();
 
   gp->set_border_width(12);
@@ -258,7 +258,7 @@ NetworkPreferencePage::create_model()
 //   Gtk::ListStore *store = peers_store.operator->();
 //   printf("%x\n", store);
 // #endif
-  
+
   list<string> peers = dist_manager->get_peers();
 
   for (list<string>::iterator i = peers.begin(); i != peers.end(); i++)
@@ -272,7 +272,7 @@ NetworkPreferencePage::create_model()
 
           string hostname, port;
           parse_peers(peer, hostname, port);
-          
+
           row[peers_columns.hostname]  = hostname;
           row[peers_columns.port]      = port;
         }
@@ -285,7 +285,7 @@ NetworkPreferencePage::parse_peers(const string &peer, string &hostname, string
 {
   hostname = "";
   port = "";
-  
+
   std::string::size_type pos = peer.find("tcp://");
   if (pos != std::string::npos)
     {
@@ -439,10 +439,10 @@ NetworkPreferencePage::on_peer_add()
 
   Gtk::TreeModel::iterator iter = peers_store->append();
   Gtk::TreeModel::Row row = *iter;
-  
+
   row[peers_columns.hostname]  = "";
   row[peers_columns.port]      = ss.str();
-  
+
   TRACE_EXIT();
 }
 
